@@ -223,6 +223,28 @@ class OSMRegion:
         """
         return [el for el in self.railway_elements if type(el) == OSMRailwaySwitch]
 
+    def get_switches_for_railway_line(self, line: OSMRailwayLine) -> List[OSMRailwaySwitch]:
+        """ Get switches part of a given railway line
+
+        Parameters
+        ----------
+        line: OSMRailwayLine
+
+        Returns
+        -------
+            list
+        """
+        switches = self.get_switches()
+
+        line_switches = []
+        for w in line.ways:
+            n_ids = [n.id for n in w.nodes]
+            for sw in switches:
+                if sw.id in n_ids:
+                    line_switches.append(sw)
+
+        return line_switches
+
     def get_signals(self) -> List[OSMRailwayElement]:
         """ Returns a list of railway signals found in the downloaded OSM region
 
